/* ***** BEGIN LICENSE BLOCK *****
 * Version: MPL 1.1/GPL 2.0/LGPL 2.1
 *
 * The contents of this file are subject to the Mozilla Public License Version
 * 1.1 (the "License"); you may not use this file except in compliance with
 * the License. You may obtain a copy of the License at
 * http://www.mozilla.org/MPL/
 *
 * Software distributed under the License is distributed on an "AS IS" basis,
 * WITHOUT WARRANTY OF ANY KIND, either express or implied. See the License
 * for the specific language governing rights and limitations under the
 * License.
 *
 * The Original Code is mozCmgui.
 *
 * The Initial Developer of the Original Code is
 * Auckland Uniservices Ltd, Auckland, New Zealand.
 * Portions created by the Initial Developer are Copyright (C) 2005
 * the Initial Developer. All Rights Reserved.
 *
 * Contributor(s):
 *
 * Alternatively, the contents of this file may be used under the terms of
 * either the GNU General Public License Version 2 or later (the "GPL"), or
 * the GNU Lesser General Public License Version 2.1 or later (the "LGPL"),
 * in which case the provisions of the GPL or the LGPL are applicable instead
 * of those above. If you wish to allow use of your version of this file only
 * under the terms of either the GPL or the LGPL, and not to allow others to
 * use your version of this file under the terms of the MPL, indicate your
 * decision by deleting the provisions above and replace them with the notice
 * and other provisions required by the GPL or the LGPL. If you do not delete
 * the provisions above, a recipient may use your version of this file under
 * the terms of any one of the MPL, the GPL or the LGPL.
 *
 * ***** END LICENSE BLOCK ***** */
#include "TimeSequenceZincXpidl.hpp"
#include "nsXPCOM.h"

CmguiTimeSequencePackage::CmguiTimeSequencePackage()
{
  /* constructor code */
}

CmguiTimeSequencePackage::~CmguiTimeSequencePackage()
{
  /* destructor code */
}

/* CmguiITimeSequence getMatchingTimeSequence ([array, size_is (sizeof_times)] in double times, in PRUint32 sizeof_times); */
NS_IMETHODIMP CmguiTimeSequencePackage::GetMatchingTimeSequence(double *times, PRUint32 sizeof_times, CmguiITimeSequence **_retval)
{
  Cmiss_time_sequence_id return_value;
  if (!(return_value = Cmiss_time_sequence_package_get_matching_time_sequence(impl, sizeof_times, times)))
  {
    return NS_ERROR_UNEXPECTED;
  }
  *_retval = new CmguiTimeSequence(return_value);
  NS_ADDREF(*_retval);
  return NS_OK;
}

/* CmguiITimeSequence getSimpleTimeSequence (in unsigned long numberOfTimes, in double firstTime, in double increment); */
NS_IMETHODIMP CmguiTimeSequencePackage::GetSimpleTimeSequence(PRUint32 numberOfTimes, double firstTime, double increment, CmguiITimeSequence **_retval)
{
	double *sequence, v;
	Cmiss_time_sequence_id return_value;
	unsigned int i;
	
	sequence = (double *)NS_Alloc(sizeof(double) * numberOfTimes);
	for (v = firstTime, i = 0; i < numberOfTimes; i++, v += increment)
    sequence[i] = v;

  if (!(return_value = Cmiss_time_sequence_package_get_matching_time_sequence(impl, numberOfTimes, sequence)))
  {
    NS_Free(sequence);
    return NS_ERROR_UNEXPECTED;
  }
  NS_Free(sequence);
  *_retval = new CmguiTimeSequence(return_value);
  NS_ADDREF(*_retval);
  return NS_OK;
}

CmguiTimeSequence::CmguiTimeSequence()
{
  /* constructor code */
}

CmguiTimeSequence::~CmguiTimeSequence()
{
  /* destructor code */
}

